.. _index:

StreamSets DataOps Platform SDK for Python
==========================================
|

The StreamSets DataOps Platform SDK for Python version 4.0.0 or greater enables users to interact with
StreamSets DataOps Platform programmatically using Python 3.4+.

.. toctree::
    :maxdepth: 3
    :hidden:

    learn
    set_up
    build
    run
    monitor
    manage
    api
